#
# spec file for package perl-Catalyst-Manual
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Catalyst-Manual
Name:           perl-Catalyst-Manual
Version:        5.901.300
Release:        1.1
# 5.9013 -> normalize -> 5.901.300
%define cpan_version 5.9013
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        The Catalyst developer's manual
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETHER/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.88
Provides:       perl(Catalyst::Manual) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
The Catalyst developer's manual

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Mon Jun 23 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Sat Mar 23 2024 Tina Müller <timueller+perl@suse.de>
- updated to 5.9013
  see /usr/share/doc/packages/perl-Catalyst-Manual/Changes
  5.9013 - 2024-03-22
  - fix mojibake in metadata
  5.9012 - 2024-02-03
  - fixed some broken links (Graham Knop, Daniel Böhmer)
* Tue Jul 28 2020 Tina Müller <timueller+perl@suse.de>
- updated to 5.9011
  see /usr/share/doc/packages/perl-Catalyst-Manual/Changes
  5.9011 - 2020-07-22
  - added NGINX Unit deployment documentation
* Sat Apr 27 2019 Stephan Kulow <coolo@suse.com>
- updated to 5.9010
  see /usr/share/doc/packages/perl-Catalyst-Manual/Changes
  5.9010 - 2019-04-25
  - updated stale urls
  - numerous typo fixes
  - many pod syntax fixes
  - other pod syntax cleanup
  - added references to the RT issues queue, mailing list, and irc channel
* Sat Feb  7 2015 coolo@suse.com
- updated to 5.9009
  - fixed a new error in the manual regarding "component" -> "components"
    (RT#99131, RT#100597, RT#100767)
  5.9008 - 2014-07-26
  - misc small documentation tweaks (thanks Karen Etheridge, Matthew
    Horsfall, Andreas Marienborg, Dagfinn Ilmari Mannsåker, David
    Steinbrunner, Gerda Shank, Jesse)
* Mon Jun  3 2013 coolo@suse.com
- updated to 5.9007
  - Fix pod warnings (RT#83398 - thanks, Paul Waring!)
  - Fix repository metadata (thanks, Lars Lars Dɪᴇᴄᴋᴏᴡ)
  - fix bad =head1 (Kennedy Clark)
  - Fix minor typos RT 78545, thanks Joe Axford
  - Update auth class name RT 77322 Thanks Joe Axford
  - Fix typo RT #77247 Thanks John Deighan
  - PSGI Compat changes
  - Small code changes (thanks sockmonk)
  - Small changes to Manual::Components
* Fri Feb 17 2012 coolo@suse.com
- updated to 5.9003
  - Mention PSGI in Manual::Ingro RT#74872 (thanks William Blunn).
  - Better docs of :Global inspired by RT#74869 (thanks William Blunn)
  - Highlight the importance of uncommenting the template line in the
    list action
  - Clarify docs for nginx in non-root - a trailing slash on the
    location block is very much needed.
  - Clarified Data::Dumper usage.  RT#71410 Thanks to Bill Corr
  - Mention Chef deployment in Manual::Deployment (thanks to Alexey
    Melezhik)
* Tue Oct 25 2011 tabraham@novell.com
- updated to 5.9002
  - Tutorial
  - Switch to 'catalyst' vs. 'root' user in VM
  - Add notes about X Windows installation
  - Misc small adjustments
- updated to 5.9001
  - Tutorial
  - Migrate Tutorial to use of a downloadable Virtual Machine
  - Switch tutorial to Catalyst::Plugin::StatusMessage (vs. flash
    and query parameters)
  - Switch to use of local::lib
  - Add "next chapter links" (RT #31164)
  - Test all the tutorial code and make sure it's all working
  - Lots of other Tutorial cleanup
  - Update to Catalyst 5.9 and latest versions of all modules
  - Clean up RT ticket queue (#68379, 68377, 68376, etc.)
  - Other misc fixes/changes
- updated to 5.9000
  - Copy editing to make more sense in deployment documentation.
- updated to 5.8901
  - Added Catalyst::Manual::Deployment containing the documentation
    which used to bin in Catalyst::Engine::*, updated for the new
    PSGI engine
- updated to 5.8008
  - Tutorial chapter 3
  - Remove note about hacking tests to require MyApp so that MyApp->path_to
    works. Application components should compile independently, and
    therefore explain this and show configuring components from the
    app class
  - Tutorial appendix
  - Fix confusing mix of singular and plural table names in the MySQL
    section to be plural, as per the rest of the tutorial
  - Cookbook
  - Remove suggestion to generate RSS feeds using Template Toolkit.
    This is a horrible idea, and it's very very easy to generate an
    invalid feed
* Sun May  1 2011 coolo@opensuse.org
- updated to 5.8007
  - Tutorial
  - Switch to use of DBIx::Class::PassphraseColumn for hashed & salted
    passwords. It's much more flexible than the previously used
    DBIx::Class::EncodedColumn.
  - Fix metadata to refer to the new git repository
  - Cookbook
  - Small fixes and typos
  - Tutorial
  - Various typo fixes.
  - RT #57989: typo
  - RT #61486: correct instructions for MySQL
  - RT #62095: prevent XSS
  - RT #62095: persistent message on /login
  - RT #63057: typo
  - RT #64087: typos
  - RT #64126: Use precise name of licence
  - RT #64126: typos
  - RT #67820: fix relationship decleration
  - Do not recommend FastMmap
  - DevelopmentProcess
  - RT #62610: typo
* Wed Jan 19 2011 coolo@novell.com
- initial package 5.8005
  * created by cpanspec 1.78.03
